@@ -1,18 +1,15 @@
 from .config import EmailURL
+from .encrypters import Encrypter
 from .exceptions import MailersError
 from .factories import add_protocol_handler, create_mailer, create_transport_from_url
 from .mailer import Mailer
-from .message import Attachment, EmailMessage
+from .message import Email
 from .plugins import BasePlugin, Plugin
-from .transports import (
-    BaseTransport,
-    FileTransport,
-    InMemoryTransport,
-    NullTransport,
-    SMTPTransport,
-    StreamTransport,
-    Transport,
-)
+from .result import SentMessage, SentMessages
+from .signers import Signer
+from .templated_mail import TemplatedEmail
+from .transports import FileTransport, InMemoryTransport, NullTransport, StreamTransport, Transport
+from .transports.smtp import SMTPTransport
 
 __all__ = [
     "Transport",
@@ -20,16 +17,19 @@ __all__ = [
     "SMTPTransport",
     "NullTransport",
     "FileTransport",
-    "BaseTransport",
     "StreamTransport",
     "MailersError",
-    "EmailMessage",
-    "Attachment",
+    "Email",
     "EmailURL",
     "Plugin",
     "BasePlugin",
+    "Signer",
+    "Encrypter",
     "Mailer",
     "create_mailer",
     "create_transport_from_url",
     "add_protocol_handler",
+    "SentMessages",
+    "SentMessage",
+    "TemplatedEmail",
 ]
